import React, { useState, useEffect, useRef } from "react";
import { FaStar } from "react-icons/fa";
import { motion } from "framer-motion";

type WatchHeroTvProps = {
  tvShow: any;
};

const WatchHeroTv: React.FC<WatchHeroTvProps> = ({ tvShow }) => {
  const [isExpanded, setIsExpanded] = useState(false); // State for read more
  const [showReadMore, setShowReadMore] = useState(false); // State to conditionally show "Read More"
  const descriptionRef = useRef<HTMLParagraphElement>(null); // Reference for description element

  const backgroundImage = `https://image.tmdb.org/t/p/original${tvShow.backdrop_path}`;
  const title = tvShow.name;
  const releaseYear = new Date(tvShow.first_air_date).getFullYear();
  const genres = tvShow.genres.map((genre: any) => genre.name).join(", ");
  const overview = tvShow.overview || "No synopsis available."; // TV Show description

  const toggleExpanded = () => setIsExpanded(!isExpanded); // Toggle description

  // Effect to check if the description exceeds 1 line
  useEffect(() => {
    const descriptionEl = descriptionRef.current;
    if (descriptionEl) {
      const lineHeight = parseFloat(window.getComputedStyle(descriptionEl).lineHeight);
      const maxHeight = 1 * lineHeight; // Calculate the height for 1 line
      if (descriptionEl.scrollHeight > maxHeight) {
        setShowReadMore(true); // Show "Read More" if content exceeds 1 line
      }
    }
  }, []);

  return (
    <div
      className="relative h-[60vh] md:h-[80vh] w-screen flex flex-col justify-end text-center bg-cover bg-center overflow-hidden"
      style={{ backgroundImage: `url(${backgroundImage})` }}
    >
      {/* Bottom fade overlay */}
      <div className="absolute inset-0 bg-gradient-to-t from-black to-transparent"></div>

      <div className="relative z-10 text-white mb-12 px-4 animate-fadeInUp">
        {/* TV Show Title */}
        <h1 className="text-3xl lg:text-5xl font-bold mb-4 animate-slideInUp">
          {title} ({releaseYear})
        </h1>

        {/* Rating, Release Date, and Genres */}
        <div className="flex justify-center items-center space-x-4 mb-2 animate-fadeIn">
          <div className="flex items-center">
            <FaStar className="h-5 w-5 text-yellow-400 mr-1" />
            <span>{tvShow.vote_average.toFixed(1)}</span>
          </div>
          <span>•</span>
          <span>{releaseYear}</span>
        </div>

        {/* Genres */}
        <p className="text-sm lg:text-lg animate-slideInUp">
          Genres: {genres}
        </p>

        {/* TV Show Description */}
        <div className="mt-4 text-sm lg:text-lg animate-slideInUp">
          {/* Conditionally show short or full description */}
          <motion.p
            ref={descriptionRef}
            className={`${
              isExpanded ? "max-h-full" : "max-h-[1.5em] overflow-hidden"
            } transition-all duration-500 ease-in-out`}
            style={{ lineClamp: !isExpanded ? 1 : "unset" }}
          >
            {overview}
          </motion.p>

          {/* Conditionally render the Read More button only if needed */}
          {showReadMore && (
            <button
              onClick={toggleExpanded}
              className="text-red-500 mt-2 underline hover:text-red-700 transition-colors duration-300"
            >
              {isExpanded ? "Show Less" : "Read More"}
            </button>
          )}
        </div>
      </div>

      <style jsx>{`
        @keyframes fadeInUp {
          from {
            opacity: 0;
            transform: translateY(20px);
          }
          to {
            opacity: 1;
            transform: translateY(0);
          }
        }

        @keyframes slideInUp {
          from {
            opacity: 0;
            transform: translateY(50px);
          }
          to {
            opacity: 1;
            transform: translateY(0);
          }
        }

        @keyframes fadeIn {
          from {
            opacity: 0;
          }
          to {
            opacity: 1;
          }
        }

        .animate-fadeInUp {
          animation: fadeInUp 1s ease-out forwards;
        }

        .animate-slideInUp {
          animation: slideInUp 1s ease-out forwards;
        }

        .animate-fadeIn {
          animation: fadeIn 1s ease-out forwards;
        }
      `}</style>
    </div>
  );
};

export default WatchHeroTv;
